@@ -17,7 +17,7 @@ class Accountant:
 
     def __init__(self, bank_account):
         self.bank_account = bank_account
-        self.ledger = LedgerClient(ledger_host="internal-prod-internal-loadbalancer-874786328.ap-southeast-1.elb.amazonaws.com/test")
+        self.ledger = LedgerClient(ledger_host="http://internal-prod-internal-loadbalancer-874786328.ap-southeast-1.elb.amazonaws.com")
 
         log.info("---------Initialising-------------")
         log.info(f"Bank Account Number:  {self.bank_account['account_id']}")
@@ -149,7 +149,7 @@ class Accountant:
     @staticmethod
     def create_book(account_id: str):
         log.info("---------New_ledger-------------")
-        ledger = LedgerClient(ledger_host="http://ledger-service-dev-1.local-dev:3000/")
+        ledger = LedgerClient(ledger_host="http://internal-prod-internal-loadbalancer-874786328.ap-southeast-1.elb.amazonaws.com")
         block_book_id = ledger.create_book(name=f"{account_id}_block_book", min_balance=0)
         main_book_id = ledger.create_book(name=f"{account_id}_main_book", min_balance=0)
         new_books = {
@@ -160,4 +160,3 @@ class Accountant:
         }
         log.info(new_books)
         return new_books
-
